package org.openxma.dsl.generator;

import java.util.Properties;

import org.eclipse.emf.common.util.URI;

/**
 * Default implementation of interface {@link GeneratorConfiguration} which uses
 * a simple property file override mechanism for determining the final set of
 * property values. <br/>
 * Properties are loaded and overridden in the following order: <br/>
 * <ol>
 * <li>default values from
 * org/openxma/dsl/generator/default-generator.properties located inside the
 * generator archive</li>
 * <li>/generator.properties from current classpath</li>
 * <li>file location as specified by the system property 'generator.properties'
 * (-Dgenerator.properties=file:/..)</li>
 * <li>{@link Properties} instance provided with the constructor of this class</li>
 * </ol>
 */
public class DefaultGeneratorConfiguration extends AbstractGeneratorConfiguration implements WebAppGeneratorConfiguration {
    private URI projectFolder;
    private URI sourceFolder;
    private URI testSourceFolder;
    private URI resourceFolder;
    private URI genSourceFolder;
    private URI genTestSourceFolder;
    private URI genResourceFolder;
    private URI webAppFolder;
    private URI genWebAppFolder;

    public DefaultGeneratorConfiguration(Properties properties) {
        super(properties);
    }

    public URI getProjectFolder() {
        return projectFolder;
    }

    public void setProjectFolder(URI projectFolder) {
        this.projectFolder = projectFolder;
    }

    public URI getSourceFolder() {
        return sourceFolder;
    }

    public void setSourceFolder(URI sourceFolder) {
        this.sourceFolder = sourceFolder;
    }

    public URI getTestSourceFolder() {
        return testSourceFolder;
    }

    public void setTestSourceFolder(URI testSourceFolder) {
        this.testSourceFolder = testSourceFolder;
    }

    public URI getResourceFolder() {
        return resourceFolder;
    }

    public void setResourceFolder(URI resourceFolder) {
        this.resourceFolder = resourceFolder;
    }

    public URI getGenSourceFolder() {
        return genSourceFolder;
    }

    public void setGenSourceFolder(URI genSourceFolder) {
        this.genSourceFolder = genSourceFolder;
    }

    public URI getGenTestSourceFolder() {
        return genTestSourceFolder;
    }

    public void setGenTestSourceFolder(URI genTestSourceFolder) {
        this.genTestSourceFolder = genTestSourceFolder;
    }

    public URI getGenResourceFolder() {
        return genResourceFolder;
    }

    public void setGenResourceFolder(URI genResourceFolder) {
        this.genResourceFolder = genResourceFolder;
    }

	public URI getWebAppFolder() {
		return webAppFolder;
	}

	public void setWebAppFolder(URI webAppFolder) {
		this.webAppFolder = webAppFolder;
	}

	public URI getGenWebAppFolder() {
		return genWebAppFolder;
	}

	public void setGenWebAppFolder(URI genWebAppFolder) {
		this.genWebAppFolder = genWebAppFolder;
	}

}
